@@ -3,7 +3,6 @@ from prompt_toolkit.completion import Completer, Completion
 from prompt_toolkit.history import InMemoryHistory
 from prompt_toolkit.shortcuts import prompt
 import click
-import click._bashcomplete
 import click.parser
 import os
 import shlex
@@ -11,6 +10,14 @@ import sys
 import six
 from .exceptions import InternalCommandException, ExitReplException  # noqa
 
+# Handle backwards compatibility between Click 7.0 and 8.0
+try: 
+    import click.shell_completion
+    HAS_C8 = True
+except ImportError:
+    import click._bashcomplete
+    HAS_C8 = False
+
 # Handle click.exceptions.Exit introduced in Click 7.0
 try:
     from click.exceptions import Exit as ClickExit
@@ -107,8 +114,12 @@ class ClickCompleter(Completer):
             # We've not entered anything, either at all or for the current
             # command, so give all relevant completions for this context.
             incomplete = ""
-
-        ctx = click._bashcomplete.resolve_ctx(self.cli, "", args)
+        # Resolve context based on click version
+        if HAS_C8:
+            ctx = click.shell_completion._resolve_context(self.cli, {}, "", args)
+        else: 
+            ctx = click._bashcomplete.resolve_ctx(self.cli, "", args)
+            
         if ctx is None:
             return
 
